@@ -14,14 +14,21 @@ class AuditlogMiddleware:
 
     @staticmethod
     def _get_remote_addr(request):
-        if request.headers.get("X-Forwarded-For"):
-            # In case of proxy, set 'original' address
-            remote_addr = request.headers.get("X-Forwarded-For").split(",")[0]
-            # Remove port number from remote_addr
-            return remote_addr.split(":")[0]
-        else:
+        # In case there is no proxy, return the original address
+        if not request.headers.get("X-Forwarded-For"):
             return request.META.get("REMOTE_ADDR")
 
+        # In case of proxy, set 'original' address
+        remote_addr: str = request.headers.get("X-Forwarded-For").split(",")[0]
+
+        # Remove port number from remote_addr
+        if "." in remote_addr and ":" in remote_addr:  # IPv4 with port (`x.x.x.x:x`)
+            remote_addr = remote_addr.split(":")[0]
+        elif "[" in remote_addr:  # IPv6 with port (`[:::]:x`)
+            remote_addr = remote_addr[1:].split("]")[0]
+
+        return remote_addr
+
     def __call__(self, request):
         remote_addr = self._get_remote_addr(request)
 
